//+------------------------------------------------------------------+
//|                                         MarketOrder Display Lines|
//+------------------------------------------------------------------+
#property version   "1.00"
#property strict
#property indicator_chart_window

//---------------------------------------------------------------------------------------------------------------------------
input string            comfons1            =  "====Display Lines====";                      //====Display Lines====
input double            Spread              =  0.00020;                                      //Spread
input double            MainTradeProfit     =  0.00050;                                      //Take Profit
input color             MarketBuy           =  clrLimeGreen;                                 //Market Buy Line
input color             BuyShading          =  clrForestGreen;                               //Buy Shading
input color             MarketSell          =  clrRed;                                       //Market Sell Line
input color             SellShading         =  clrIndigo;                                    //Sell Shading

//---------------------------------------------------------------------------------------------------------------------------
int cur_bar;

//---------------------------------------------------------------------------------------------------------------------------
int OnInit()
  {
   cur_bar=1;
   ChartSetInteger(0,CHART_EVENT_MOUSE_MOVE,true);
   return(INIT_SUCCEEDED);
  }

//---------------------------------------------------------------------------------------------------------------------------
int OnCalculate(const int rates_total,
                const int prev_calculated,
                const datetime &time[],
                const double &open[],
                const double &high[],
                const double &low[],
                const double &close[],
                const long &tick_volume[],
                const long &volume[],
                const int &spread[])
  {
   ShowInfo();
   ShowLines();
   return(rates_total);
  }

//---------------------------------------------------------------------------------------------------------------------------
void OnTimer()
  {
  
  }

//---------------------------------------------------------------------------------------------------------------------------
void OnDeinit(const int reason)
  {
   EventKillTimer();
   deinitall();
  }

//---------------------------------------------------------------------------------------------------------------------------
void deinitall()
  {
   ObjectsDeleteAll(0,"text_",0,OBJ_LABEL);
   ObjectsDeleteAll(0,"hline_",0,OBJ_HLINE);
   ObjectsDeleteAll(0,"rect_",0,OBJ_RECTANGLE);
   ObjectsDeleteAll(0,"Rect A",0,OBJ_RECTANGLE);
   ObjectsDeleteAll(0,"Rect B",0,OBJ_RECTANGLE);  
  }
 
//---------------------------------------------------------------------------------------------------------------------------
void OnChartEvent(const int id,
                  const long &lparam,
                  const double &dparam,
                  const string &sparam)
  {
   ChartSetInteger(0,CHART_EVENT_MOUSE_MOVE,true);
   if(id==CHARTEVENT_MOUSE_MOVE)
     {
      datetime _time;
      double   _price;
      int      window=0;
      ChartXYToTimePrice(0,int(lparam),int(dparam),window,_time,_price);
      cur_bar=iBarShift(NULL,0,_time);
     }
   ObjectsDeleteAll(0,"hline_",0,OBJ_HLINE);
   ShowInfo();
   ShowLines();
  }


//---------------------------------------------------------------------------------------------------------------------------
void ShowInfo()
  {
// Calculates Market Buy & Sell Levels
   double BuyStop=Close[cur_bar]+Spread;
   double BuyTP=Close[cur_bar]+MainTradeProfit+Spread;
   double SellStop=Close[cur_bar];
   double SellTP=Close[cur_bar]-MainTradeProfit;
   ObjectsDeleteAll(0,"rect_",0,OBJ_RECTANGLE);

// Draws Market Buy Line In LimeGreen Color
   draw_line("buystop",BuyStop,MarketBuy,STYLE_SOLID,2);
   draw_line("buytp",BuyTP,MarketBuy,STYLE_SOLID,2);
   
// Shades Region Between Buy Entry Price & Buy Take Profit In ForestGreen Color
   draw_rect("Rect A",Time[Bars-1],BuyStop,Time[0],BuyTP,BuyShading);

// Draws Market Sell Line In Red Color
   draw_line("SellStop",SellStop,MarketSell,STYLE_SOLID,2);
   draw_line("SellTP",SellTP,MarketSell,STYLE_SOLID,2);

// Shades Region Between Sell Entry Price & Sell Take Profit In Indigo Color
   draw_rect("Rect B",Time[Bars-1],SellStop,Time[0],SellTP,SellShading);
   
   int _spread=int(MarketInfo(NULL,MODE_SPREAD));
  }
  

//---------------------------------------------------------------------------------------------------------------------------
void draw_line(string _name,double _price,color _clr,ENUM_LINE_STYLE _style,int _width=1)
  {
   ObjectCreate(0,"hline_"+_name,OBJ_HLINE,0,0,0);
   ObjectSetDouble(0,"hline_"+_name,OBJPROP_PRICE1,_price);
   ObjectSetInteger(0,"hline_"+_name,OBJPROP_COLOR,_clr);
   ObjectSetInteger(0,"hline_"+_name,OBJPROP_STYLE,_style);
   ObjectSetInteger(0,"hline_"+_name,OBJPROP_WIDTH,_width);
   ChartRedraw(0);
  }


//---------------------------------------------------------------------------------------------------------------------------
void ShowLines()
  {

  }


//---------------------------------------------------------------------------------------------------------------------------
void draw_rect(string obj_name,datetime time1,double price1,datetime time2,double price2,color _col)
  {
   ObjectCreate(0,obj_name,OBJ_RECTANGLE,0,0,0,0,0);
   ObjectSetInteger(0,obj_name,OBJPROP_TIME1,time1);
   ObjectSetInteger(0,obj_name,OBJPROP_TIME2,time2);
   ObjectSetDouble(0,obj_name,OBJPROP_PRICE1,price1);
   ObjectSetDouble(0,obj_name,OBJPROP_PRICE2,price2);
   ObjectSetInteger(0,obj_name,OBJPROP_COLOR,_col);
  }